@@ -15,7 +15,12 @@ from fastapi.middleware.wsgi import WSGIMiddleware
 from prometheus_client import Counter, Histogram, Summary, Info
 from prometheus_client import make_wsgi_app
 from prometheus_client import REGISTRY as PROMETHEUS_REGISTRY
-from prometheus_client import CollectorRegistry, generate_latest, multiprocess
+from prometheus_client import (
+    CollectorRegistry,
+    generate_latest,
+    multiprocess,
+    CONTENT_TYPE_LATEST,
+)
 
 # from prometheus_client
 from werkzeug.middleware.dispatcher import DispatcherMiddleware
@@ -274,18 +279,25 @@ class PrometheusMiddleware(metaclass=SingletonMeta):
 
         if self.is_multiprocessing:
             clear_multiproc_dir()
-            # MULTIPROC_DIR = os.environ["PROMETHEUS_MULTIPROC_DIR"]
-            # if MULTIPROC_DIR:
-            #     file_path = Path(MULTIPROC_DIR)
-            #     if not os.path.isdir(file_path):
-            #         os.mkdir(file_path)
 
-            @self.app.route("/metrics", methods=["GET"])
-            def metrics():
-                """Return metrics."""
-                registry = CollectorRegistry()
-                multiprocess.MultiProcessCollector(registry)
-                return generate_latest(registry), 200
+            def make_wsgi_multiprocess_app():
+                def app_multiprocess(environ, start_response):
+                    registry = CollectorRegistry()
+                    multiprocess.MultiProcessCollector(registry)
+                    data = generate_latest(registry)
+                    status = "200 OK"
+                    response_headers = [
+                        ("Content-type", CONTENT_TYPE_LATEST),
+                        ("Content-Length", str(len(data))),
+                    ]
+                    start_response(status, response_headers)
+                    return iter([data])
+
+                return app_multiprocess
+
+            self.app.wsgi_app = DispatcherMiddleware(
+                self.app.wsgi_app, {"/metrics": make_wsgi_multiprocess_app()}
+            )
 
         else:
             self.app.wsgi_app = DispatcherMiddleware(
